==> zio-aws-route53resolver_2.13-5.17.123.1-sources.jar: zio/aws/route53resolver/model/DisassociateFirewallRuleGroupResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DisassociateFirewallRuleGroupResponse(
    firewallRuleGroupAssociation: Option[
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.DisassociateFirewallRuleGroupResponse = {
    import DisassociateFirewallRuleGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.DisassociateFirewallRuleGroupResponse
      .builder()
      .optionallyWith(
        firewallRuleGroupAssociation.map(value => value.buildAwsValue())
      )(_.firewallRuleGroupAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.DisassociateFirewallRuleGroupResponse.ReadOnly =
    zio.aws.route53resolver.model.DisassociateFirewallRuleGroupResponse
      .wrap(buildAwsValue())
}
object DisassociateFirewallRuleGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.DisassociateFirewallRuleGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.DisassociateFirewallRuleGroupResponse =
      zio.aws.route53resolver.model.DisassociateFirewallRuleGroupResponse(
        firewallRuleGroupAssociation.map(value => value.asEditable)
      )
    def firewallRuleGroupAssociation: Option[
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation.ReadOnly
    ]
    def getFirewallRuleGroupAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "firewallRuleGroupAssociation",
      firewallRuleGroupAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.DisassociateFirewallRuleGroupResponse
  ) extends zio.aws.route53resolver.model.DisassociateFirewallRuleGroupResponse.ReadOnly {
    override val firewallRuleGroupAssociation: Option[
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation.ReadOnly
    ] = scala
      .Option(impl.firewallRuleGroupAssociation())
      .map(value =>
        zio.aws.route53resolver.model.FirewallRuleGroupAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.DisassociateFirewallRuleGroupResponse
  ): zio.aws.route53resolver.model.DisassociateFirewallRuleGroupResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53resolver_2.13-5.17.195.1-sources.jar: zio/aws/route53resolver/model/DisassociateFirewallRuleGroupResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DisassociateFirewallRuleGroupResponse(
    firewallRuleGroupAssociation: Optional[
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.DisassociateFirewallRuleGroupResponse = {
    import DisassociateFirewallRuleGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.DisassociateFirewallRuleGroupResponse
      .builder()
      .optionallyWith(
        firewallRuleGroupAssociation.map(value => value.buildAwsValue())
      )(_.firewallRuleGroupAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.DisassociateFirewallRuleGroupResponse.ReadOnly =
    zio.aws.route53resolver.model.DisassociateFirewallRuleGroupResponse
      .wrap(buildAwsValue())
}
object DisassociateFirewallRuleGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.DisassociateFirewallRuleGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.DisassociateFirewallRuleGroupResponse =
      zio.aws.route53resolver.model.DisassociateFirewallRuleGroupResponse(
        firewallRuleGroupAssociation.map(value => value.asEditable)
      )
    def firewallRuleGroupAssociation: Optional[
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation.ReadOnly
    ]
    def getFirewallRuleGroupAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "firewallRuleGroupAssociation",
      firewallRuleGroupAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.DisassociateFirewallRuleGroupResponse
  ) extends zio.aws.route53resolver.model.DisassociateFirewallRuleGroupResponse.ReadOnly {
    override val firewallRuleGroupAssociation: Optional[
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.firewallRuleGroupAssociation())
      .map(value =>
        zio.aws.route53resolver.model.FirewallRuleGroupAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.DisassociateFirewallRuleGroupResponse
  ): zio.aws.route53resolver.model.DisassociateFirewallRuleGroupResponse.ReadOnly =
    new Wrapper(impl)
}
